@@ -60,8 +60,6 @@ from .common import (
 )
 from .engine import Engine, Result
 from .constants import (
-    _B64ALPHABET,
-    _DATE_FMT,
     _DEFAULT_INTERFACE,
     _DEFAULT_TABLE,
     _FWMARK,
@@ -73,7 +71,6 @@ from .constants import (
     _ORGANIZE_HOSTS_FILE,
     _ORGANIZE_KEYS_CONF_FILE,
     _ORGANIZE_UPDATE_TEMP,
-    _CSIDH_PRIVATE_KEY_FILE,
     _ORGANIZE_DBUS_NAME,
     _ORGANIZE_DBUS_PATH,
     _DISCOVER_DBUS_NAME,
@@ -341,7 +338,7 @@ class OrganizeState(Engine, yamlrepr_hl):
             # FIXME: this doesn't specify the routing table. maybe need to make
             # triggers api accept kwargs too?
             self.result.add_triggers(
-                remove_routes=('0.0.0.0/1', '128.0.0.0/1')
+                remove_routes=(('0.0.0.0/1', '128.0.0.0/1'),)
             )
             # these routes are currently only removed because we still call
             # sync (aka full repair) on system state change
